@@ -1,7 +1,7 @@
 package Perinci::Examples::CLI;
 
 our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.57'; # VERSION
+our $VERSION = '0.58'; # VERSION
 
 use 5.010001;
 use strict;
@@ -222,7 +222,7 @@ _
         output => {
             summary => 'Specify output filename',
             schema => 'str*',
-            "x.schema.entity" => "file",
+            "x.schema.entity" => "filename",
             description => <<'_',
 
 This option demonstrates how the option would be displayed in the help/usage.
@@ -323,7 +323,7 @@ Perinci::Examples::CLI - Example for CLI help/usage generation
 
 =head1 VERSION
 
-This document describes version 0.57 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2015-09-03.
+This document describes version 0.58 of Perinci::Examples::CLI (from Perl distribution Perinci-Examples), released on 2015-09-03.
 
 =head1 SEE ALSO
 
